@@ -8,6 +8,7 @@ AVAILABLE_LANGUAGES = [
     ('fr',           N_('French')),
     ('nl',           N_('Dutch')),
     ('sv_SE',        N_('Swedish')),
+    ('po_BR',        N_('Brazilian Portuguese')),
     ('zh_CN',        N_('Chinese Simplified'))
 ]
 
@@ -21,6 +22,7 @@ HANDLERS = [
     ('scgi',         N_('SCGI')),
     ('uwsgi',        N_('uWSGI')),
     ('proxy',        N_('HTTP reverse proxy')),
+    ('post_report',  N_('Upload reporting')),
     ('streaming',    N_('Audio/Video streaming')),
     ('cgi',          N_('CGI')),
     ('ssi',          N_('Server Side Includes')),
@@ -176,3 +178,15 @@ UTC_TIME = [
     ('',         N_('Local time')),
     ('1',        N_('UTC: Coordinated Universal Time'))
 ]
+
+DWRITER_LANGS = [
+    ('json',     N_('JSON')),
+    ('python',   N_('Python')),
+    ('php',      N_('PHP')),
+    ('ruby',     N_('Ruby'))
+]
+
+POST_TRACKERS = [
+    ('',           N_('Disabled')),
+    ('post_track', N_('POST tracker'))
+]
