@@ -164,13 +164,6 @@ e('VALIDATOR_METHOD_UNKNOWN',
   desc  = BROKEN_CONFIG)
 
 
-# cherokee/downloader.c
-#
-e('DOWNLOADER_OVERWRITE_POST',
-  title = "Overwriting post info",
-  desc  = CODING_BUG)
-
-
 # cherokee/admin_client.c
 #
 e('ADMIN_CLIENT_INTERNAL',
@@ -266,6 +259,13 @@ e('HANDLER_DIRLIST_BAD_THEME',
   desc  = "Most likely someone has inadvertedly deleted some of the files of your theme. Please try to restore the files or change your theme selection.")
 
 
+# cherokee/handler_post_report.c
+#
+e('HANDLER_POST_REPORT_LANG',
+  title = "Unrecognized language '%s'",
+  desc  = "Cherokee's POST status reporter supports a number of output languages and formats, including: JSON, Python, PHP and Ruby.")
+
+
 # cherokee/handler_dbslayer.c
 #
 e('HANDLER_DBSLAYER_LANG',
@@ -744,13 +744,6 @@ e('CONF_READ_PARSE',
   debug = "%s")
 
 
-# cherokee/post.c
-#
-e('POST_REMOVE_TEMP',
-  title = "Could not remove temporal file",
-  desc  = "The temporal file '%s' could not be removed.")
-
-
 # cherokee/template.c
 #
 e('TEMPLATE_NO_TOKEN',
