@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2009 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2010 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -63,8 +63,7 @@ typedef ret_t (* cherokee_handler_cgi_base_read_from_cgi_t) (cherokee_handler_cg
 typedef enum {
 	hcgi_phase_build_headers,
 	hcgi_phase_connect,
-	hcgi_phase_send_headers,
-	hcgi_phase_send_post
+	hcgi_phase_send_headers
 } cherokee_handler_cgi_base_phase_t;
 
 /* Data structure
