@@ -630,9 +630,15 @@ send_post (cherokee_handler_proxy_t *hdl)
 	ret_t                     ret;
 	cherokee_connection_t    *conn     = HANDLER_CONN(hdl);
 	cherokee_socket_status_t  blocking = socket_closed;
+	cherokee_boolean_t        did_IO   = false;
+
+	ret = cherokee_post_send_to_socket (&conn->post, &conn->socket,
+					    &hdl->pconn->socket, NULL, &blocking, &did_IO);
+
+	if (did_IO) {
+		cherokee_connection_update_timeout (conn);
+	}
 
-	ret = cherokee_post_send_to_socket (&conn->post, conn, &conn->socket,
-					    &hdl->pconn->socket, NULL, &blocking);
 	switch (ret) {
 	case ret_ok:
 		break;
